@@ -56,8 +56,7 @@ const char *ScriptChecks::chkKeywords(Line *line, ScriptImage *img)
 	if(!line->argc)
 		return "keyword list missing";
 
-	while(NULL != (cp = getOption(line, &idx)))
-	{
+	while(NULL != (cp = getOption(line, &idx))) {
 		if(!isalpha(*cp) && !isdigit(*cp))
 			return "invalid keyword entry";
 	}
@@ -102,8 +101,7 @@ const char *ScriptChecks::chkCall(Line *line, ScriptImage *img)
 	if(*cp == '&')
 		++cp;
 
-	if(strchr(cp, ':') || stricmp(line->cmd, "call"))
-	{
+	if(strchr(cp, ':') || stricmp(line->cmd, "call")) {
 		snprintf(proto, sizeof(proto), "keywords.%s", cp);
 		list = (Line *)img->getPointer(proto);
 	}
@@ -125,14 +123,12 @@ const char *ScriptChecks::chkCall(Line *line, ScriptImage *img)
 		return NULL;
 
 	idx = 0;
-	while(NULL != (cp = getOption(list, &idx)))
-	{
+	while(NULL != (cp = getOption(list, &idx))) {
 		snprintf(proto + len, sizeof(proto) - len, "=%s", cp);
 		len = (unsigned)strlen(proto);
 	}
 
-	if(len)
-	{
+	if(len) {
 		if(!useKeywords(line, proto))
 			return "invalid keyword used for function call";
 	}
@@ -317,8 +313,7 @@ const char *ScriptChecks::chkSlog(Line *line, ScriptImage *img)
 {
 	const char *member = getMember(line);
 
-	if(member)
-	{
+	if(member) {
 		if(!stricmp(member, ".debug"))
 			member = NULL;
 		else if(!stricmp(member, ".info"))
@@ -399,8 +394,7 @@ const char *ScriptChecks::chkExpr(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && !isdigit(cp[0]))
-	{
+	if(cp && !isdigit(cp[0])) {
 		cp = chkProperty(line, img);
 
 		if(cp)
@@ -448,12 +442,10 @@ const char *ScriptChecks::chkDefine(Line *line, ScriptImage *img)
 	if(!line->argc)
 		return "define requires arguments";
 
-	while(idx < line->argc)
-	{
+	while(idx < line->argc) {
 		cp = line->args[idx++];
 
-		if(*cp == '=')
-		{
+		if(*cp == '=') {
 			++cp;
 			++idx;
 		}
@@ -465,8 +457,7 @@ const char *ScriptChecks::chkDefine(Line *line, ScriptImage *img)
 			++cp;
 
 		cp = strchr(cp, ':');
-		if(cp)
-		{
+		if(cp) {
 			++cp;
 			if(!isdigit(*cp))
 				return "invalid field size used";
@@ -490,8 +481,7 @@ const char *ScriptChecks::chkVar(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && !isdigit(cp[0]))
-	{
+	if(cp && !isdigit(cp[0])) {
 		cp = chkProperty(line, img);
 		if(!cp)
 			return "property invalid for var";
@@ -574,8 +564,7 @@ const char *ScriptChecks::chkExpression(Line *line, ScriptImage *img)
 	unsigned paren = 0;
 	const char *cp;
 
-	while(NULL != (cp = getOption(line, &idx)))
-	{
+	while(NULL != (cp = getOption(line, &idx))) {
 		if(*cp == '(')
 			++paren;
 		else if(*cp == ')')
@@ -596,10 +585,8 @@ const char *ScriptChecks::chkAllVars(Line *line, ScriptImage *img)
 	unsigned idx = 0;
 	const char *cp;
 
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		switch(*cp)
-		{
+	while(NULL != (cp = getOption(line, &idx))) {
+		switch(*cp) {
 		case '%':
 		case '@':
 		case '&':
